@@ -7,9 +7,9 @@ use warnings;
 use PerlX::Maybe;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-01-27'; # DATE
+our $DATE = '2023-02-10'; # DATE
 our $DIST = 'App-td'; # DIST
-our $VERSION = '0.108'; # VERSION
+our $VERSION = '0.109'; # VERSION
 
 our %SPEC;
 
@@ -145,6 +145,7 @@ has functionality similar to some Unix commands like *head*, *tail*, *wc*,
 lines/characters. This is convenient to use with CLI scripts that output table
 data.
 
+
 **What is table data?**
 
 A _table data_ is JSON-encoded data in the form of either: `hos` (hash of
@@ -158,12 +159,38 @@ The input can also be an _enveloped_ table data, where the envelope is an array:
 kind of data is produced by `Perinci::CmdLine`-based scripts and can contain
 more detailed table specification in the `meta` hash, which `td` can parse.
 
-If you have a CSV, you can easily convert it to table data using the *csv2td*
-utility:
+
+**What scripts/modules output table data?**
+
+CLI scripts that are written using <pm:Perinci::CmdLine> framework output
+enveloped table data. There are at least hundreds of such scripts on CPAN. Some
+examples include: <prog:lcpan> (from <pm:App::lcpan>), <prog:pmlist> (from
+<pm:App::PMUtils>), and <prog:bencher> (from <pm:Bencher>).
+
+`TableData::*` modules contain table data. They can easily be output to CLI
+using the <prog:tabledata> utility (from <pm:App::TableDataUtils>).
+
+CSV output from any module/script can be easily converted to table data using
+the <prog:csv2td> utility:
 
     % csv2td YOUR.csv | td ...
     % program-that-outputs-csv | csv2td - | td ...
 
+Table data can also be converted from several other formats e.g. JSON, YAML,
+XLS/XLSX/ODS.
+
+
+**What scripts/modules accept table data?**
+
+This *td* script, for one, accept table data.
+
+If a module/script expects CSV, you can feed table data and convert it to CSV
+using <prog:td2csv> utility.
+
+Several other formats can also be converted to table data, e.g. JSON,
+YAML, XLS/XLSX/ODS.
+
+
 **Using td**
 
 First you might want to use the `info` action to see if the input is a table
@@ -900,7 +927,7 @@ App::td - Manipulate table data
 
 =head1 VERSION
 
-This document describes version 0.108 of App::td (from Perl distribution App-td), released on 2023-01-27.
+This document describes version 0.109 of App::td (from Perl distribution App-td), released on 2023-02-10.
 
 =head1 FUNCTIONS
 
@@ -934,12 +961,35 @@ C<[status, message, content, meta]> and C<content> is the actual table data. Thi
 kind of data is produced by C<Perinci::CmdLine>-based scripts and can contain
 more detailed table specification in the C<meta> hash, which C<td> can parse.
 
-If you have a CSV, you can easily convert it to table data using the I<csv2td>
-utility:
+B<What scripts/modules output table data?>
+
+CLI scripts that are written using L<Perinci::CmdLine> framework output
+enveloped table data. There are at least hundreds of such scripts on CPAN. Some
+examples include: L<lcpan> (from L<App::lcpan>), L<pmlist> (from
+L<App::PMUtils>), and L<bencher> (from L<Bencher>).
+
+C<TableData::*> modules contain table data. They can easily be output to CLI
+using the L<tabledata> utility (from L<App::TableDataUtils>).
+
+CSV output from any module/script can be easily converted to table data using
+the L<csv2td> utility:
 
  % csv2td YOUR.csv | td ...
  % program-that-outputs-csv | csv2td - | td ...
 
+Table data can also be converted from several other formats e.g. JSON, YAML,
+XLS/XLSX/ODS.
+
+B<What scripts/modules accept table data?>
+
+This I<td> script, for one, accept table data.
+
+If a module/script expects CSV, you can feed table data and convert it to CSV
+using L<td2csv> utility.
+
+Several other formats can also be converted to table data, e.g. JSON,
+YAML, XLS/XLSX/ODS.
+
 B<Using td>
 
 First you might want to use the C<info> action to see if the input is a table
